# Cont

This is set of sctipts to fast run containers for local development.

Just install it using `pip` or `pipx` and start using.

```bash
pipx install my-cont 
```

Install autocompletion by running:

```bash
cont --install-completion
```

By defaul if you specify container name the corresponding named volume is going to 
be created where it's possible.